@@ -90,7 +90,7 @@ def create_video(list_comp_data, path_video, job_id):
         final_clip.close()
     else:
         if audio_compilation_path is None:
-            raise Exception("Audio Compulation Error!!!")
+            raise Exception("Audio Compilation Error!!!")
         cnt_real_duration=0
         while max_real_duration < 60*2/3 and cnt_real_duration<2 and cnt_effect_vid>1:
             max_real_duration*=2
