@@ -22,7 +22,7 @@ def create_compilation_songs(data, job_id):
     file_merg_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4())
     file_merg = open(file_merg_path, "a")
     final_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-final.mp3'
-
+    cnt_song=0
     try:
         for song in arr_songs:
             try:
@@ -70,6 +70,7 @@ def create_compilation_songs(data, job_id):
                     song['local']=tmp_clip_path
 
                 file_merg.write("file '%s'\n" % os.path.basename(song['local']))
+                cnt_song+=1
             except:
                 pass
         file_merg.close()
@@ -83,6 +84,15 @@ def create_compilation_songs(data, job_id):
                 pass
     except:
         pass
+    if cnt_song == 0:
+        return None
+    try:
+        audio_moviepy = AudioFileClip(final_clip_path)
+        if audio_moviepy.duration < 1:
+            final_clip_path=None
+        audio_moviepy.close()
+    except:
+        pass
     return final_clip_path
 
 
